@@ -1,3 +1,4 @@
+import curses
 import code
 import sys
 import traceback
@@ -7,7 +8,7 @@ from kaa import document
 from kaa.keyboard import *
 from kaa.filetype.default import defaultmode
 from kaa.filetype.python import pythonmode
-from kaa.command import command, Commands, norec, norerun
+from kaa.command import commandid, Commands, norec, norerun
 from kaa.theme import Theme, Style
 from kaa.ui.dialog import dialogmode
 from kaa.ui.inputline import inputlinemode
@@ -26,7 +27,6 @@ PythonConsoleThemes = {
     ],
 }
 
-
 class KaaInterpreter(code.InteractiveInterpreter):
 
     def runcode(self, code):
@@ -44,6 +44,7 @@ class PythonConsoleMode(pythonmode.PythonMode):
     DEFAULT_STATUS_MSG = 'Hit alt+Enter for history.'
     MODENAME = 'Python console'
     DOCUMENT_MODE = False
+    SHOW_BLANK_LINE = False
 
     PYTHONCONSOLE_KEY_BINDS = [
         pythonconsole_keys,
@@ -139,7 +140,7 @@ class PythonConsoleMode(pythonmode.PythonMode):
         sys.stdout = stdout
         sys.stderr = stderr
 
-    @command('python.exec')
+    @commandid('python.exec')
     @norec
     @norerun
     def exec_script(self, wnd):
@@ -147,7 +148,12 @@ class PythonConsoleMode(pythonmode.PythonMode):
         f, t = self.document.marks['current_script']
         s = wnd.document.gettext(f, t).lstrip()
         with self._redirect_output(wnd):
-            ret = self.interp.runsource(s)
+            curses.cbreak()
+            try:
+                ret = self.interp.runsource(s)
+            finally:
+                curses.raw()
+
             if not ret:
                 if s.strip():
                     hist = kaa.app.config.hist(
@@ -188,7 +194,7 @@ class PythonConsoleMode(pythonmode.PythonMode):
 
     MAX_HISTORY = 100
 
-    @command('python.script-history')
+    @commandid('python.script-history')
     @norec
     @norerun
     def history(self, wnd):
@@ -202,9 +208,9 @@ class PythonConsoleMode(pythonmode.PythonMode):
                 self._put_script(wnd, text)
 
         from kaa.ui.texthist import texthistmode
-        texthistmode.show_history(callback, scripts)
+        texthistmode.show_history('Search history:',callback, scripts)
 
-    @command('edit.paste')
+    @commandid('edit.paste')
     def paste(self, wnd):
         s = kaa.app.clipboard.get()
         if s:
@@ -248,7 +254,7 @@ class PythonInputlineMode(dialogmode.DialogMode, pythonmode.PythonMode):
         popup.destroy()
         kaa.app.messagebar.set_message("Canceled")
 
-    @command('inputline')
+    @commandid('inputline')
     @norec
     @norerun
     def input_line(self, w):
